# script_librerias
this  lib has been to create to have all the daily and useful function we use inside Businness Intelligence Team at Minor Hotels.

## Installation

using pip:
```bash
pip install nh_lib